@@ -76,6 +76,10 @@ def get_tool_list() -> List[BMTool]:
     from cryoloBM_tools.make_autopick_star import MakeAutopickStar
     autpick_tool = MakeAutopickStar()
     tools.append(autpick_tool)
+
+    from cryoloBM_tools.class_2d_extract import class_2d_extract
+    class2d_tool = class_2d_extract()
+    tools.append(class2d_tool)
     '''
     from cryoloBM_tools.make_cryosparc_starfile import MakeCryoSparcStar
     cc_tool = MakeCryoSparcStar()
