@@ -1,3 +1,8 @@
+"""
+In this this file are defined a list of various helper functions (and an helper class):
+-) create parser: manage the parser
+"""
+
 import argparse
 import numpy as np
 from math import isnan
