@@ -189,7 +189,7 @@ def convert(
             micrographname = micrographname + ".tomostar"
             first_column = '_rlnMicrographName'
         else:
-            micrographname = micrographname + ".star"
+            #micrographname = micrographname + ".star"
             first_column = '_rlnTomoName'
         columns = [first_column, '_rlnCoordinateX', '_rlnCoordinateY', '_rlnCoordinateZ']
         if magnification:
@@ -214,7 +214,7 @@ def convert(
             if pixelsize:
                 rlndata[i, columns.index("_rlnDetectorPixelSize")] = pixelsize
             if has_fid:
-                rlndata[i, columns.index("_rlnHelicalTubeID")] = row[3]
+                rlndata[i, columns.index("_rlnHelicalTubeID")] = row[3]+1
 
 
 
@@ -228,7 +228,7 @@ def convert(
             df['_rlnAnglePsiFlipRatio'] = flip_ratio
 
         df.iloc[:,0] = micrographname
-        if not warp_style:
+        if has_fid and not warp_style:
             df = df.drop('_rlnHelicalTubeID', axis=1)
         all_relion_data.append(df)
 
